@@ -1,15 +1,7 @@
-from os import getenv
-import subprocess
 import pandas as pd
 import mariadb
 import sys
 from elasticsearch import Elasticsearch
-import spacy
-
-if not spacy.util.is_package("es_core_news_md"):
-    subprocess.run("python -m spacy download es_core_news_md")
-      
-nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
 
 
 
