@@ -3,6 +3,14 @@ from spacy import load as LOAD
 from spacy.matcher import Matcher
 from collections import Counter
 import matplotlib.pyplot as plt
+from spacy import util as util
+import subprocess
+
+if not util.is_package("es_core_news_md"):
+    subprocess.run("python -m spacy download es_core_news_md")
+    print("instalando el modelo de leguanje 'es_core_news_md', el kernel será reiniciado, porfavor vuelva a ejecutar su codigo")
+else:  
+    nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
 
 nlp = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
 matcher = Matcher(nlp.vocab)
